/// <reference types="nock" />
import * as nock from "nock";
export declare type httpMethod = "GET" | "HEAD" | "POST" | "PATCH" | "PUT" | "DELETE" | "OPTIONS";
export declare type HttpDomain = string | RegExp;
export declare type RelativeUrl = string | RegExp;
export interface InterceptorParams {
    basePath: HttpDomain;
    method: httpMethod;
    relativeUrl: RelativeUrl;
    times: number;
}
export interface HttpHeaders {
    [key: string]: string;
}
export interface PartialInterceptor {
    reply(status: number, body?: any, headers?: HttpHeaders): Interceptor;
    replyWithError(error: any): Interceptor;
    replyWithFile(status: number, filename: string, headers?: HttpHeaders): Interceptor;
    times(times: number): PartialInterceptor;
}
export interface Interceptor {
    callCount: number;
    original: nock.Interceptor;
    header(key: string): string;
    header(key: string): string;
    headers(...keys: Array<string>): HttpHeaders;
    allHeaders(...keys: Array<string>): Array<HttpHeaders>;
    query(): object;
    queries(): Array<object>;
    body(): object;
    bodies(): Array<object>;
    url(): string;
    urls(): Array<string>;
}
export interface PartialScope {
    get(uri: string): PartialInterceptor;
    head(uri: string): PartialInterceptor;
    post(uri: string): PartialInterceptor;
    patch(uri: string): PartialInterceptor;
    put(uri: string): PartialInterceptor;
    delete(uri: string): PartialInterceptor;
    options(uri: string): PartialInterceptor;
}
export interface Heisennock {
    (basePath: HttpDomain): PartialScope;
    cleanAll: () => void;
}
declare const heisennock: Heisennock;
export default heisennock;
export declare function cleanAll(): void;
